@@ -1,18 +1,18 @@
 package App::ThisDist;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2021-06-22'; # DATE
-our $DIST = 'App-ThisDist'; # DIST
-our $VERSION = '0.011'; # VERSION
-
 use strict;
 use warnings;
 use Log::ger;
 
+use Exporter qw(import);
 use File::chdir;
 
-use Exporter qw(import);
-our @EXPORT_OK = qw(this_dist);
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-11-28'; # DATE
+our $DIST = 'App-ThisDist'; # DIST
+our $VERSION = '0.012'; # VERSION
+
+our @EXPORT_OK = qw(this_dist this_mod);
 
 sub this_dist {
     require File::Slurper;
@@ -209,7 +209,7 @@ App::ThisDist - Print Perl {distribution,module,author,...} associated with curr
 
 =head1 VERSION
 
-This document describes version 0.011 of App::ThisDist (from Perl distribution App-ThisDist), released on 2021-06-22.
+This document describes version 0.012 of App::ThisDist (from Perl distribution App-ThisDist), released on 2021-11-28.
 
 =head1 DESCRIPTION
 
@@ -225,12 +225,6 @@ See included scripts:
 
 
 
-=head1 CONTRIBUTOR
-
-=for stopwords perlancar (on netbook-dell-xps13)
-
-perlancar (on netbook-dell-xps13) <perlancar@gmail.com>
-
 =head1 FUNCTIONS
 
 =head2 this_dist
@@ -256,14 +250,6 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-ThisDi
 
 Source repository is at L<https://github.com/perlancar/perl-App-ThisDist>.
 
-=head1 BUGS
-
-Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ThisDist>
-
-When submitting a bug or request, please include a test-file or a
-patch to an existing test-file that illustrates the bug or desired
-feature.
-
 =head1 SEE ALSO
 
 L<App::DistUtils>
@@ -272,11 +258,36 @@ L<App::DistUtils>
 
 perlancar <perlancar@cpan.org>
 
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla plugin and/or Pod::Weaver::Plugin. Any additional steps required
+beyond that are considered a bug and can be reported to me.
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2021, 2020 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2020 by perlancar <perlancar@cpan.org>.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ThisDist>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
 =cut
